@@ -4,11 +4,14 @@ from .controllers import TvController
 from .controllers import AcController
 from .controllers import MultiCommandDeviceController
 from .controllers import MultiCommandRgbLampController
+from durc import Model
 from .models import PluginsModel, RgbLampsModel, RgbLampStatesModel, DevicesModel
 from .models import TvsModel, TvStatesModel
 from .models import AcsModel, AcStatesModel
+from .models import ScenesModel
 from .models import MultiCommandDevicesModel, CommandsModel
 from .models import MultiCommandRgbLampsModel
 from .models import DeviceStatesModel, clone
+from .models import ColorsModel
 from .managers import Manager, PluginManager
-from .utils import hex_to_rgb, rgb_to_hex
+from .utils import hex_to_rgb, rgb_to_hex, int_to_hex_color
