@@ -13,14 +13,18 @@ class PluginController(Controller):
     def module_name(self): return self.model.module_name
 
 
+    @property
+    def active(self): return self.model.active
+
+
     def __init__(self):
         self.module = None
         self.ctrl_cls = {}
         self.controllers = {}
 
 
-    def on_load(self, **data):
-        pass
+    def toggle_active(self):
+        self.model.update(active=not self.model.active)
 
 
     def init(self):
