@@ -1,9 +1,10 @@
-from .device_model import DevicesModel, DeviceStatesModel
+from .device_model import DevicesModel, DeviceStatesModel, PingableDevicesModel
 from .colors_model import ColorsModel
 from .multi_command_devices_model import MultiCommandDevicesModel, CommandsModel
-from .multi_command_rgb_lamps_model import MultiCommandRgbLampsModel
+from .multi_command_rgb_lamps_model import MultiCommandRgbLampsModel, ColorCommandsModel
 from .rgb_light_model import RgbLampsModel, RgbLampStatesModel
 from .acs_model import AcsModel, AcStatesModel
 from .tvs_model import TvsModel, TvStatesModel
 from .plugins_model import PluginsModel
+from .scene_model import ScenesModel
 from durc import clone
