@@ -1,4 +1,5 @@
-from durc import Model, clone
+from durc import Model
+from ..utils import rgb_to_hex
 
 
 class ColorsModel(Model):
@@ -8,3 +9,10 @@ class ColorsModel(Model):
         'name': { 'type': 'string', 'default': '' },
         'rgb': { 'type': 'list', 'default': [255, 255, 255] },
     }
+
+
+    def to_dict(self):
+        return {
+            **super().to_dict(),
+            'hex': rgb_to_hex(*self.rgb),
+        }
