@@ -1,14 +1,22 @@
 from .rgb_light_model import RgbLampsModel
-from .multi_command_devices_model import MultiCommandDevicesModel
+from .multi_command_devices_model import MultiCommandDevicesModel, CommandsModel
+from .colors_model import ColorsModel
 from durc import Model, clone
 
 
 class ColorCommandsModel(Model):
-    schema = clone(Model.schema) | {
-        'color_id': { 'type': 'string', 'required': True },
-        'command_id': { 'type': 'string', 'required': True },
+    children_model_classes = {
+        'color': { 'class': ColorsModel, 'quantity': 1 },
+        'command': { 'class': CommandsModel, 'quantity': 1 },
     }
 
+    def to_dict(self):
+        return {
+            **super().to_dict(),
+            'color': self.color.to_dict(),
+            'command': self.command.to_dict(),
+        }
+
 
 class MultiCommandRgbLampsModel(MultiCommandDevicesModel, RgbLampsModel):
     schema = clone(RgbLampsModel.schema) | {
