@@ -1,20 +1,8 @@
 from math import sqrt
 
 
-def get_base_classes(cls):
-    r = [cls]
-    for b in cls.__bases__:
-        if b.__name__ != 'object':
-            r.extend(get_base_classes(b))
-    return r
-
-
-def get_methods_in(*classes):
-    r = []
-    for cls in classes:
-        methods = [(key, f) for key, f in cls.__dict__.items() if callable(f)]
-        r.extend(methods)
-    return r
+def int_to_hex_color(int_rgb):
+    return str.format('#{:06x}', int(int_rgb))
 
 
 def hex_to_rgb(hex_code):
